pub trait TableUpdate<FE>: TableInstance
where FE: AsType<Node> + ThreadSafe,
{ // Required methods fn truncate<'life0, 'async_trait>( &'life0 self, txn_id: TxnId, range: Range, tmp: BTreeLock<BTreeSchema, ValueCollator, FE> ) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn update<'life0, 'async_trait>( &'life0 self, txn_id: TxnId, range: Range, values: Map<Value>, tmp: BTreeLock<BTreeSchema, ValueCollator, FE> ) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; }
The Table update method

Required Methods

source

fn truncate<'life0, 'async_trait>( &'life0 self, txn_id: TxnId, range: Range, tmp: BTreeLock<BTreeSchema, ValueCollator, FE> ) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Delete all rows in the given range from this table.

source

fn update<'life0, 'async_trait>( &'life0 self, txn_id: TxnId, range: Range, values: Map<Value>, tmp: BTreeLock<BTreeSchema, ValueCollator, FE> ) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Update all rows in range with the given values.

Implementors

source

impl<Txn, FE> TableUpdate<FE> for Table<Txn, FE>
where Txn: Transaction<FE>, FE: AsType<Node> + ThreadSafe,

source

impl<Txn, FE> TableUpdate<FE> for TableFile<Txn, FE>
where Txn: Transaction<FE>, FE: AsType<Node> + ThreadSafe,