Trait tc_collection::table::TableUpdate
source · pub trait TableUpdate<FE>: TableInstance{
// Required methods
fn truncate<'life0, 'async_trait>(
&'life0 self,
txn_id: TxnId,
range: Range,
tmp: BTreeLock<BTreeSchema, ValueCollator, FE>
) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn update<'life0, 'async_trait>(
&'life0 self,
txn_id: TxnId,
range: Range,
values: Map<Value>,
tmp: BTreeLock<BTreeSchema, ValueCollator, FE>
) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
The Table update method
Required Methods
sourcefn truncate<'life0, 'async_trait>(
&'life0 self,
txn_id: TxnId,
range: Range,
tmp: BTreeLock<BTreeSchema, ValueCollator, FE>
) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn truncate<'life0, 'async_trait>(
&'life0 self,
txn_id: TxnId,
range: Range,
tmp: BTreeLock<BTreeSchema, ValueCollator, FE>
) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Delete all rows in the given range from this table.
sourcefn update<'life0, 'async_trait>(
&'life0 self,
txn_id: TxnId,
range: Range,
values: Map<Value>,
tmp: BTreeLock<BTreeSchema, ValueCollator, FE>
) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn update<'life0, 'async_trait>(
&'life0 self,
txn_id: TxnId,
range: Range,
values: Map<Value>,
tmp: BTreeLock<BTreeSchema, ValueCollator, FE>
) -> Pin<Box<dyn Future<Output = TCResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Update all rows in range with the given values.